SystemOrganization addCategory: #ConfigurationOfDaliotsPlayground!

!MetacelloMCVersion methodsFor: '*ConfigurationOfDaliotsPlayground' stamp: 'HwaJong 10/17/2013 15:22'!
loadPackageFromUser
	| packages usersPackageIndex |
	packages := spec packageNames asSortedCollection.
	usersPackageIndex := UIManager default chooseFrom: packages title: 'package to load'.
	usersPackageIndex > 0 ifTrue: [(packages at: usersPackageIndex) loadRequiredForMetacelloMCVersion: self]
	! !

!MetacelloMCVersion methodsFor: '*ConfigurationOfDaliotsPlayground' stamp: 'HwaJong 10/17/2013 18:51'!
loadUnloadedPackageFromUser
	| packages usersPackageIndex loader unloadedSpecs mcLoader |
	loader := MetacelloMCVersionSpecLoader on: self spec.
	loader required: (self specNames).
	loaderPolicy notNil ifTrue: [ loader loaderPolicy: loaderPolicy ].
	loader resolvePackageNames.
	loader resolveToLoadableSpecs.
	mcLoader := loader loader.
			loader packages values do: [:pkg | 
				pkg ensureLoadedForDevelopmentUsing: mcLoader.
				mcLoader ignoreImage ifFalse: [(pkg 
					compareCurrentVersion: loader operator 
					targetVersionStatus: #(allLoadedToSpec) 
					using: mcLoader) 
						ifTrue: [ loader packages removeKey: pkg name ]]].
	unloadedSpecs := mcLoader spec packageSpecsInLoadOrder.
	packages := (unloadedSpecs collect: #name) asSortedCollection.
	usersPackageIndex := UIManager default chooseFrom: packages title: 'package to load from unloaded packages'.
	usersPackageIndex > 0 ifTrue: [(packages at: usersPackageIndex) loadRequiredForMetacelloMCVersion: self]
	! !

!MetacelloMCVersion methodsFor: '*ConfigurationOfDaliotsPlayground' stamp: 'HwaJong 10/17/2013 18:53'!
specNames
	|names|
	names := OrderedCollection new.
	self spec projectDo: [:pr| names add: pr name] packageDo: [:pk| names add: pk name] groupDo: [:gp| names add: gp name ].
	^names! !

Object subclass: #ConfigurationOfDaliotsPlayground
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!ConfigurationOfDaliotsPlayground class methodsFor: 'private' stamp: 'hjo 7/3/2011 02:51'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'private' stamp: 'hjo 7/3/2011 02:51'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'hjo 7/3/2011 02:51'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'hjo 7/3/2011 02:51'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'loading' stamp: 'hjo 7/3/2011 02:51'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'hjo 7/3/2011 02:51'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'accessing' stamp: 'hjo 7/3/2011 02:51'!
project

	^self new project! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'HwaJong 12/23/2013 17:09'!
update

	Gofer new
		repository: (MCHttpRepository
	location: 'http://smalltalkhub.com/mc/HwaJong/DaliotsPlayground/main');
		package: 'GlueGun';
		package: 'ConfigurationOfDaliotsPlayground';
		load.! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'HwaJong 9/21/2013 10:55'!
validate 
	self validateDaleStyle.
	self validateFailingVersionsAndWhy.! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'HwaJong 9/21/2013 10:54'!
validateDaleStyle
	(MetacelloToolBox validateConfiguration: self) explore.! !

!ConfigurationOfDaliotsPlayground class methodsFor: 'metacello tool support' stamp: 'HwaJong 9/21/2013 10:55'!
validateFailingVersionsAndWhy
	| failingVersionsAndWhy project |
	project := ConfigurationOfDaliotsPlayground project.
	failingVersionsAndWhy := OrderedCollection new.
	project versions do: [:each| [each printString] on: Error do: [:error| failingVersionsAndWhy add: (error messageText -> each versionNumber)]].
	failingVersionsAndWhy explore.! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 2/13/2014 20:34'!
baseline86: spec 
	| baselineVersionString classes operation |
	<version: '8.6-baseline'>
	classes := self baselineClasses.
	baselineVersionString := self baselineVersionStringFromMethodContext: thisContext.
	operation := [:each| each defineSpec: spec forBaselineVersionString: baselineVersionString ].
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://smalltalkhub.com/mc/HwaJong/DaliotsPlayground/main'.
		(classes select: #isCommonSI)  do: operation.
		spec for: #OB do: [ (classes select: #isCommonOBSI)  do: operation ].
		].
	spec for: #'pharo2.0.x' do: [ (classes select: #isPharo2SI)  do: operation ].
	spec for: #'pharo3.0.x' do: [ (classes select: #isPharo3SI)  do: operation ].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 3/3/2014 22:03'!
baseline87: spec 
	| baselineVersionString classes operation |
	<version: '8.7-baseline'>
	classes := self baselineClasses.
	baselineVersionString := self baselineVersionStringFromMethodContext: thisContext.
	operation := [:each| each defineSpec: spec forBaselineVersionString: baselineVersionString ].
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://smalltalkhub.com/mc/HwaJong/DaliotsPlayground/main'.
		(classes select: #isCommonSI)  do: operation.
		spec for: #OB do: [ (classes select: #isCommonOBSI)  do: operation ].
		].
	spec for: #'pharo2.0.x' do: [ (classes select: #isPharo2SI)  do: operation ].
	spec for: #'pharo3.0.x' do: [ (classes select: #isPharo3SI)  do: operation ].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'baselines' stamp: 'HwaJong 3/25/2014 21:01'!
baseline88: spec 
	| baselineVersionString classes operation |
	<version: '8.8-baseline'>
	classes := self baselineClasses.
	baselineVersionString := self baselineVersionStringFromMethodContext: thisContext.
	operation := [:each| each defineSpec: spec forBaselineVersionString: baselineVersionString ].
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://smalltalkhub.com/mc/HwaJong/DaliotsPlayground/main'.
		(classes select: #isCommonSI)  do: operation.
		spec for: #OB do: [ (classes select: #isCommonOBSI)  do: operation ].
		].
	spec for: #'pharo2.0.x' do: [ (classes select: #isPharo2SI)  do: operation ].
	spec for: #'pharo3.0.x' do: [ (classes select: #isPharo3SI)  do: operation ].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'accessing' stamp: 'HwaJong 2/13/2014 20:57'!
baselineClasses

	^SpecItem concreteSubclasses! !

!ConfigurationOfDaliotsPlayground methodsFor: 'accessing' stamp: 'HwaJong 2/12/2014 03:30'!
baselineVersionStringFromMethodContext: aMethodContext

	^(aMethodContext method pragmas detect: [ :ea| ea key = #version: ]) arguments anyOne! !

!ConfigurationOfDaliotsPlayground methodsFor: 'attributes' stamp: 'hjo 8/2/2012 10:45'!
customProjectAttributes

	Smalltalk at: ##OBCodeBrowser ifPresent: [:ignored | ^#(#OB) ].
    ^#()! !

!ConfigurationOfDaliotsPlayground methodsFor: 'script' stamp: 'HwaJong 10/26/2013 02:15'!
disintegrateDevPacerFromTheSystem
	#PacerBase ifGlobalExistThenPerform: #disintegratePacersFromTheSystem! !

!ConfigurationOfDaliotsPlayground methodsFor: 'script' stamp: 'HwaJong 10/26/2013 02:15'!
integrateDevPacerToTheSystem
	#PacerBase ifGlobalExistThenPerform: #integratePacersToTheSystem! !

!ConfigurationOfDaliotsPlayground methodsFor: 'accessing' stamp: 'hjo 8/2/2012 12:40'!
project
    ^ project
        ifNil: [ 
            "Bootstrap Metacello if it is not already loaded"
            self class ensureMetacello.
            project := MetacelloMCProject new projectAttributes: self customProjectAttributes.	"Create the Metacello project"
            (Smalltalk at: #'MetacelloVersionConstructor') on: self project: project.	"Construct the project"
            project loadType: #'linear'.	"change to #atomic if desired"
            project ]! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 2/13/2014 17:50'!
version210: spec 
	| vs classes operation |
	<version: '21.0' imports: #('8.6-baseline') >
	" 12 February 2014"
	vs := self versionStringFromMethodContext: thisContext.
	classes := self baselineClasses.
	operation := [:each | each defineSpec: spec withVersionString: vs ].
	spec for: #common do: [
		spec blessing: #development.
		(classes select: #isCommonSI) do: operation.
		].
	spec for: #'pharo2.0.x' do: [ (classes select: #isPharo2SI) do: operation ].
	spec for: #'pharo3.0.x' do: [ (classes select: #isPharo3SI) do: operation ].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/6/2014 13:37'!
version211: spec 
	| vs classes operation |
	<version: '21.1' imports: #('8.7-baseline') >
	" 3 March 2014"
	vs := self versionStringFromMethodContext: thisContext.
	classes := self baselineClasses.
	operation := [:each | each defineSpec: spec withVersionString: vs ].
	spec for: #common do: [
		spec blessing: #development.
		(classes select: #isCommonSI) do: operation.
		].
	spec for: #'pharo2.0.x' do: [ (classes select: #isPharo2SI) do: operation ].
	spec for: #'pharo3.0.x' do: [ (classes select: #isPharo3SI) do: operation ].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/6/2014 13:37'!
version212: spec 
	| vs classes operation |
	<version: '21.2' imports: #('8.7-baseline') >
	" 3 March 2014"
	vs := self versionStringFromMethodContext: thisContext.
	classes := self baselineClasses.
	operation := [:each | each defineSpec: spec withVersionString: vs ].
	spec for: #common do: [
		spec blessing: #development.
		(classes select: #isCommonSI) do: operation.
		].
	spec for: #'pharo2.0.x' do: [ (classes select: #isPharo2SI) do: operation ].
	spec for: #'pharo3.0.x' do: [ (classes select: #isPharo3SI) do: operation ].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'versions' stamp: 'HwaJong 3/25/2014 20:56'!
version213: spec 
	| vs classes operation |
	<version: '21.3' imports: #('8.8-baseline') >
	"25 March 2014"
	vs := self versionStringFromMethodContext: thisContext.
	classes := self baselineClasses.
	operation := [:each | each defineSpec: spec withVersionString: vs ].
	spec for: #common do: [
		spec blessing: #development.
		(classes select: #isCommonSI) do: operation.
		].
	spec for: #'pharo2.0.x' do: [ (classes select: #isPharo2SI) do: operation ].
	spec for: #'pharo3.0.x' do: [ (classes select: #isPharo3SI) do: operation ].! !

!ConfigurationOfDaliotsPlayground methodsFor: 'accessing' stamp: 'HwaJong 2/12/2014 03:39'!
versionStringFromMethodContext: aMethodContext

	^aMethodContext method pragmas anyOne arguments first! !

Object subclass: #SpecItem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

SpecItem subclass: #BaselineItem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

BaselineItem subclass: #AllBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!AllBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!AllBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 04:19'!
mczVersionNameFromMetacelloVersionString: aString
	^'All-HwaJong.2'! !

BaselineItem subclass: #AniBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!AniBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!AniBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:54'!
dependingOnForVersion: aString
	^{SortDescriptorsBI. LazyRabbitBI. DaliotBI}! !

!AniBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 12:59'!
mczVersionNameFromMetacelloVersionString: aString
	^'Ani-HwaJong.46'! !

BaselineItem subclass: #AppleScriptProgrammerBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!AppleScriptProgrammerBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!AppleScriptProgrammerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:56'!
dependingOnForVersion: aString
	^{DependencySorterBI}! !

!AppleScriptProgrammerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 13:02'!
mczVersionNameFromMetacelloVersionString: aString
	^'AppleScriptProgrammer-hjo.13'! !

BaselineItem subclass: #ArtificalMouseClickBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!ArtificalMouseClickBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!ArtificalMouseClickBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 13:09'!
mczVersionNameFromMetacelloVersionString: aString
	^'ArtificalMouseClick-HwaJong.2'! !

BaselineItem subclass: #BarnSwallowBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!BarnSwallowBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!BarnSwallowBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 13:11'!
mczVersionNameFromMetacelloVersionString: aString
	^'BarnSwallow-HwaJong.1'! !

!BaselineItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:51'!
defineSpec: spec forBaselineVersionString: aString 
	spec package: self packageName with: [spec requires: (self namesOfDependingOnForVersion: aString)].! !

!BaselineItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 03:46'!
defineSpec: spec withVersionString: aString 
	spec package: self packageName with: (self mczVersionNameFromMetacelloVersionString: aString).! !

!BaselineItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:52'!
dependingOnForVersion: aString
	^{}! !

!BaselineItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:53'!
namesOfDependingOnForVersion: aString
	^(self dependingOnForVersion: aString) collect: #specName! !

!BaselineItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 01:53'!
packageName
	^self specName! !

!BaselineItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 01:50'!
postFix

	^'BI'! !

BaselineItem subclass: #BetterArgumentNameByDebuggerBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!BetterArgumentNameByDebuggerBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!BetterArgumentNameByDebuggerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:54'!
mczVersionNameFromMetacelloVersionString: aString
	^'BetterArgumentNameByDebugger-HwaJong.4'! !

BaselineItem subclass: #BetterMethodCategoryBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!BetterMethodCategoryBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!BetterMethodCategoryBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:14'!
isCommonSI
	^false! !

!BetterMethodCategoryBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:15'!
isPharo2SI
	^true! !

!BetterMethodCategoryBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:17'!
mczVersionNameFromMetacelloVersionString: aString
	^'BetterMethodCategory-HwaJong.1'! !

BaselineItem subclass: #BinarySearchBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!BinarySearchBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!BinarySearchBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:56'!
dependingOnForVersion: aString
	^{NumericalErrorBI}! !

!BinarySearchBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 13:17'!
mczVersionNameFromMetacelloVersionString: aString
	^'BinarySearch-HwaJong.9'! !

BaselineItem subclass: #BlackBoxParserBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!BlackBoxParserBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!BlackBoxParserBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:56'!
dependingOnForVersion: aString
	^{HashProofBI}! !

!BlackBoxParserBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 13:15'!
mczVersionNameFromMetacelloVersionString: aString
	^'BlackBoxParser-hjo.12'! !

BaselineItem subclass: #BloodTypeBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!BloodTypeBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!BloodTypeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:56'!
dependingOnForVersion: aString
	^{MultiDimensionalEnumerationBI}! !

!BloodTypeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 13:20'!
mczVersionNameFromMetacelloVersionString: aString
	^'BloodType-hjo.2'! !

BaselineItem subclass: #CenterStringBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!CenterStringBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!CenterStringBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 13:24'!
mczVersionNameFromMetacelloVersionString: aString
	^'CenterString-HwaJong.2'! !

BaselineItem subclass: #ChooseOrEnterBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!ChooseOrEnterBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!ChooseOrEnterBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 3/4/2014 02:06'!
mczVersionNameFromMetacelloVersionString: aString
	|mvn|
	mvn := MetacelloVersionNumber fromString: aString.
	(mvn >= (MetacelloVersionNumber fromString: '21.0')) ifTrue: [^'ChooseOrEnter-HwaJong.4'].
	^'ChooseOrEnter-HwaJong.3'! !

BaselineItem subclass: #ClassFilterBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!ClassFilterBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!ClassFilterBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 13:35'!
mczVersionNameFromMetacelloVersionString: aString
	^'ClassFilter-HwaJong.6'! !

BaselineItem subclass: #CoolEnumerationsBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!CoolEnumerationsBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!CoolEnumerationsBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:24'!
mczVersionNameFromMetacelloVersionString: aString
	^'CoolEnumerations-HwaJong.1'! !

BaselineItem subclass: #CopyHierarchyBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!CopyHierarchyBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!CopyHierarchyBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:59'!
dependingOnForVersion: aString
	^{MoveClassBI}! !

!CopyHierarchyBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:26'!
mczVersionNameFromMetacelloVersionString: aString
	^'CopyHierarchy-HwaJong.14'! !

BaselineItem subclass: #CroquisBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!CroquisBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!CroquisBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:59'!
dependingOnForVersion: aString
	^{MoveClassBI}! !

!CroquisBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:27'!
mczVersionNameFromMetacelloVersionString: aString
	^'Croquis-HwaJong.16'! !

BaselineItem subclass: #DaliotBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DaliotBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!DaliotBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:59'!
dependingOnForVersion: aString
	^{CoolEnumerationsBI}! !

!DaliotBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:29'!
mczVersionNameFromMetacelloVersionString: aString
	^'Daliot-HwaJong.144'! !

BaselineItem subclass: #DaliotsMappersBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DaliotsMappersBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!DaliotsMappersBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:59'!
dependingOnForVersion: aString
	^{RangeBI}! !

!DaliotsMappersBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:45'!
mczVersionNameFromMetacelloVersionString: aString
	^'DaliotsMappers-HwaJong.8'! !

BaselineItem subclass: #DefragFATBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DefragFATBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!DefragFATBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 19:56'!
dependingOnForVersion: aString
	^{RangeBI. DaliotBI}! !

!DefragFATBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:47'!
mczVersionNameFromMetacelloVersionString: aString
	^'DefragFAT-hjo.50'! !

BaselineItem subclass: #DependencySorterBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DependencySorterBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!DependencySorterBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:00'!
dependingOnForVersion: aString
	^{LazyRabbitBI}! !

!DependencySorterBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:49'!
mczVersionNameFromMetacelloVersionString: aString
	^'DependencySorter-hjo.3'! !

BaselineItem subclass: #DeprecatorBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DeprecatorBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!DeprecatorBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:51'!
mczVersionNameFromMetacelloVersionString: aString
	^'Deprecator-HwaJong.2'! !

BaselineItem subclass: #DevHelpersBaseBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DevHelpersBaseBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!DevHelpersBaseBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:52'!
mczVersionNameFromMetacelloVersionString: aString
	^'DevHelpersBase-HwaJong.1'! !

BaselineItem subclass: #DevPacerCommonBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DevPacerCommonBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!DevPacerCommonBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:03'!
defineSpec: spec withVersionString: aString 
	spec package: self packageName 
		with: 
			[spec preLoadDoIt: #disintegrateDevPacerFromTheSystem.
			spec file: 'DevPacerCommon-HwaJong.56'].! !

!DevPacerCommonBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:00'!
dependingOnForVersion: aString
	^{DevHelpersBaseBI. AniBI}! !

!DevPacerCommonBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:31'!
isCommonSI
	^false! !

BaselineItem subclass: #DevPacerPharo20BI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DevPacerPharo20BI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!DevPacerPharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:41'!
isCommonSI
	^false! !

!DevPacerPharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:34'!
isPharo2SI
	^false! !

!DevPacerPharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:34'!
isPharo3SI
	^false! !

!DevPacerPharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:51'!
mczVersionNameFromMetacelloVersionString: aString
	^'DevPacerPharo20-HwaJong.5'! !

BaselineItem subclass: #DiceRollerBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DiceRollerBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!DiceRollerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:01'!
dependingOnForVersion: aString
	^{BlackBoxParserBI. CoolEnumerationsBI}! !

!DiceRollerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:53'!
mczVersionNameFromMetacelloVersionString: aString
	^'DiceRoller-hjo.3'! !

BaselineItem subclass: #DijEvolutionBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DijEvolutionBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!DijEvolutionBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:01'!
dependingOnForVersion: aString
	^{SortDescriptorsBI}! !

!DijEvolutionBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:55'!
mczVersionNameFromMetacelloVersionString: aString
	^'DijEvolution-HwaJong.27'! !

BaselineItem subclass: #DistinctionBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DistinctionBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!DistinctionBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 14:56'!
mczVersionNameFromMetacelloVersionString: aString
	^'Distinction-HwaJong.2'! !

BaselineItem subclass: #DoNCollectNBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DoNCollectNBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!DoNCollectNBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:05'!
mczVersionNameFromMetacelloVersionString: aString
	^'DoNCollectN-HwaJong.1'! !

BaselineItem subclass: #DocumentLogicBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DocumentLogicBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!DocumentLogicBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:06'!
mczVersionNameFromMetacelloVersionString: aString
	^'DocumentLogic-HwaJong.25'! !

BaselineItem subclass: #FastDetectorBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!FastDetectorBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!FastDetectorBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:01'!
dependingOnForVersion: aString
	^{LazyRabbitBI}! !

!FastDetectorBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:07'!
mczVersionNameFromMetacelloVersionString: aString
	^'FastDetector-HwaJong.2'! !

BaselineItem subclass: #FiguresBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!FiguresBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!FiguresBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:17'!
mczVersionNameFromMetacelloVersionString: aString
	^'Figures-HwaJong.1'! !

BaselineItem subclass: #GGControllerBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!GGControllerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 3/25/2014 21:03'!
dependingOnForVersion: aString
	^{TGListModelBI}! !

!GGControllerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 3/25/2014 21:02'!
mczVersionNameFromMetacelloVersionString: aString
	^'GGController-HwaJong.1'! !

BaselineItem subclass: #GlueGunBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!GlueGunBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!GlueGunBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 04:00'!
mczVersionNameFromMetacelloVersionString: aString
	^'GlueGun-HwaJong.6'! !

BaselineItem subclass: #GraphBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!GraphBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:02'!
dependingOnForVersion: aString
	^{HashProofBI. SortDescriptorsBI. LazyRabbitBI}! !

!GraphBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 03:48'!
mczVersionNameFromMetacelloVersionString: aString
	^'Graph-HwaJong.19'! !

BaselineItem subclass: #GroomingBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!GroomingBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!GroomingBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:18'!
mczVersionNameFromMetacelloVersionString: aString
	^'Grooming-HwaJong.2'! !

BaselineItem subclass: #HangmanRescueBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!HangmanRescueBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!HangmanRescueBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:19'!
mczVersionNameFromMetacelloVersionString: aString
	^'HangmanRescue-hjo.1'! !

BaselineItem subclass: #HashProofBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!HashProofBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 3/6/2014 13:40'!
mczVersionNameFromMetacelloVersionString: aString
	|mvn|
	mvn := MetacelloVersionNumber fromString: aString.
	(mvn >= (MetacelloVersionNumber fromString: '21.2')) ifTrue: [^'HashProof-HwaJong.10'].
	^'HashProof-HwaJong.9'! !

BaselineItem subclass: #ImageFamilyTreeBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!ImageFamilyTreeBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!ImageFamilyTreeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:02'!
dependingOnForVersion: aString
	^{BinarySearchBI}! !

!ImageFamilyTreeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:15'!
mczVersionNameFromMetacelloVersionString: aString
	^'ImageFamilyTree-HwaJong.28'! !

BaselineItem subclass: #ImageFootprintBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!ImageFootprintBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!ImageFootprintBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:19'!
mczVersionNameFromMetacelloVersionString: aString
	^'ImageFootprint-HwaJong.16'! !

BaselineItem subclass: #InteractiveBisectBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!InteractiveBisectBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!InteractiveBisectBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:02'!
dependingOnForVersion: aString
	^{LazyRabbitBI}! !

!InteractiveBisectBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:09'!
mczVersionNameFromMetacelloVersionString: aString
	^'InteractiveBisect-HwaJong.13'! !

BaselineItem subclass: #JBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!JBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!JBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:02'!
dependingOnForVersion: aString
	^{MultiQuoAndRemBI. HashProofBI. DaliotBI}! !

!JBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:44'!
mczVersionNameFromMetacelloVersionString: aString
	^'J-HwaJong.5'! !

BaselineItem subclass: #JihacholBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!JihacholBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!JihacholBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:03'!
dependingOnForVersion: aString
	^{StatPseudoCollectionsBI . LazyRabbitBI . MaxClubBI . GraphBI. MultiDimensionalEnumerationBI}! !

!JihacholBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:21'!
mczVersionNameFromMetacelloVersionString: aString
	^'Jihachol-HwaJong.37'! !

BaselineItem subclass: #LazyRabbitBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!LazyRabbitBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!LazyRabbitBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 04:02'!
mczVersionNameFromMetacelloVersionString: aString
	^'LazyRabbit-HwaJong.35'! !

BaselineItem subclass: #LearnCanvasBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!LearnCanvasBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!LearnCanvasBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:22'!
mczVersionNameFromMetacelloVersionString: aString
	^'LearnCanvas-HwaJong.7'! !

BaselineItem subclass: #MailSortingOfficeBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!MailSortingOfficeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:03'!
dependingOnForVersion: aString
	^{UndoRedoBI}! !

!MailSortingOfficeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 17:57'!
mczVersionNameFromMetacelloVersionString: aString
	^'MailSortingOffice-HwaJong.11'! !

BaselineItem subclass: #MaxClubBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!MaxClubBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!MaxClubBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:24'!
mczVersionNameFromMetacelloVersionString: aString
	^'MaxClub-hjo.8'! !

BaselineItem subclass: #MorphoPhysicsBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!MorphoPhysicsBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!MorphoPhysicsBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:04'!
dependingOnForVersion: aString
	^{LazyRabbitBI}! !

!MorphoPhysicsBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:16'!
mczVersionNameFromMetacelloVersionString: aString
	^'MorphoPhysics-HwaJong.35'! !

BaselineItem subclass: #MoveClassBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!MoveClassBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!MoveClassBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 16:26'!
mczVersionNameFromMetacelloVersionString: aString
	^'MoveClass-HwaJong.1'! !

BaselineItem subclass: #MultiDimensionalEnumerationBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!MultiDimensionalEnumerationBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!MultiDimensionalEnumerationBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:04'!
dependingOnForVersion: aString
	^{MultiQuoAndRemBI. LazyRabbitBI}! !

!MultiDimensionalEnumerationBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 17:45'!
mczVersionNameFromMetacelloVersionString: aString
	^'MultiDimensionalEnumeration-HwaJong.12'! !

BaselineItem subclass: #MultiQuoAndRemBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!MultiQuoAndRemBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!MultiQuoAndRemBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 17:46'!
mczVersionNameFromMetacelloVersionString: aString
	^'MultiQuoAndRem-HwaJong.4'! !

BaselineItem subclass: #NumericalErrorBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!NumericalErrorBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!NumericalErrorBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 17:47'!
mczVersionNameFromMetacelloVersionString: aString
	^'NumericalError-HwaJong.1'! !

BaselineItem subclass: #ObjectDiffBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!ObjectDiffBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!ObjectDiffBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:04'!
dependingOnForVersion: aString
	^{LazyRabbitBI}! !

!ObjectDiffBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:44'!
mczVersionNameFromMetacelloVersionString: aString
	^'ObjectDiff-HwaJong.64'! !

BaselineItem subclass: #ObjectSheetBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!ObjectSheetBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!ObjectSheetBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:05'!
dependingOnForVersion: aString
	^{LazyRabbitBI. WaffleLayoutBI}! !

!ObjectSheetBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:44'!
mczVersionNameFromMetacelloVersionString: aString
	^'ObjectSheet-HwaJong.29'! !

BaselineItem subclass: #PCubeBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!PCubeBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!PCubeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:05'!
dependingOnForVersion: aString
	^{MaxClubBI}! !

!PCubeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 18:09'!
mczVersionNameFromMetacelloVersionString: aString
	^'PCube-HwaJong.12'! !

BaselineItem subclass: #PhileasFoggBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!PhileasFoggBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!PhileasFoggBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:05'!
dependingOnForVersion: aString
	^{LazyRabbitBI. SortDescriptorsBI. UndoRedoBI}! !

!PhileasFoggBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 18:10'!
mczVersionNameFromMetacelloVersionString: aString
	^'PhileasFogg-hjo.36'! !

BaselineItem subclass: #PlotterBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!PlotterBI commentStamp: '' prior: 0!
A GraphBI is xxxxxxxxx.
!

!PlotterBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:06'!
dependingOnForVersion: aString
	^{DaliotsMappersBI. DaliotBI. LazyRabbitBI}! !

!PlotterBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 18:11'!
mczVersionNameFromMetacelloVersionString: aString
	^'Plotter-HwaJong.10'! !

BaselineItem subclass: #PocketCubeBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!PocketCubeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:06'!
dependingOnForVersion: aString
	^{HashProofBI. LazyRabbitBI. WaffleLayoutBI. DijEvolutionBI}! !

!PocketCubeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:27'!
mczVersionNameFromMetacelloVersionString: aString
	^'PocketCube-HwaJong.177'! !

BaselineItem subclass: #PredicatesBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!PredicatesBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 3/20/2014 07:34'!
mczVersionNameFromMetacelloVersionString: aString
	^'Predicates-HwaJong.1'! !

BaselineItem subclass: #PrintingDifferentlyBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!PrintingDifferentlyBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 17:55'!
mczVersionNameFromMetacelloVersionString: aString
	^'PrintingDifferently-HwaJong.2'! !

BaselineItem subclass: #ProgressReporterMorphBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!ProgressReporterMorphBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:06'!
dependingOnForVersion: aString
	^{QuickPrototypingGI}! !

!ProgressReporterMorphBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 01:58'!
mczVersionNameFromMetacelloVersionString: aString
	^'ProgressReporterMorph-HwaJong.1'! !

BaselineItem subclass: #PrologBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!PrologBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:06'!
dependingOnForVersion: aString
	^{HashProofBI. MultiDimensionalEnumerationBI}! !

!PrologBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 01:59'!
mczVersionNameFromMetacelloVersionString: aString
	^'Prolog-HwaJong.19'! !

BaselineItem subclass: #PullUpToSuperclassBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!PullUpToSuperclassBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:07'!
dependingOnForVersion: aString
	^{MoveClassBI. GlueGunBI}! !

!PullUpToSuperclassBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:45'!
mczVersionNameFromMetacelloVersionString: aString
	^'PullUpToSuperclass-HwaJong.17'! !

BaselineItem subclass: #QuantumLogicBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!QuantumLogicBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:07'!
dependingOnForVersion: aString
	^{HashProofBI. CoolEnumerationsBI. MultiDimensionalEnumerationBI}! !

!QuantumLogicBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:45'!
mczVersionNameFromMetacelloVersionString: aString
	^'QuantumLogic-HwaJong.39'! !

BaselineItem subclass: #QuickPrototypingCommonBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!QuickPrototypingCommonBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:07'!
dependingOnForVersion: aString
	^{QuickPrototypingGI}! !

!QuickPrototypingCommonBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 3/25/2014 21:13'!
mczVersionNameFromMetacelloVersionString: aString
	|mvn|
	mvn := MetacelloVersionNumber fromString: aString.
	(mvn >= (MetacelloVersionNumber fromString: '21.3')) ifTrue: [^'QuickPrototypingCommon-HwaJong.14'].
	(mvn >= (MetacelloVersionNumber fromString: '21.0')) ifTrue: [^'QuickPrototypingCommon-HwaJong.12'].
	^'QuickPrototypingCommon-HwaJong.8'! !

BaselineItem subclass: #QuickPrototypingPharo20BI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!QuickPrototypingPharo20BI commentStamp: '' prior: 0!
A QuickPrototypingCommonBI is xxxxxxxxx.
!

!QuickPrototypingPharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:56'!
isPharo2SI
	^true! !

!QuickPrototypingPharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:54'!
isPharo3SI
	^true! !

!QuickPrototypingPharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:52'!
mczVersionNameFromMetacelloVersionString: aString
	^'QuickPrototypingPharo20-HwaJong.1'! !

BaselineItem subclass: #RangeBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!RangeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:07'!
dependingOnForVersion: aString
	^{SortDescriptorsBI. HashProofBI}! !

!RangeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:00'!
mczVersionNameFromMetacelloVersionString: aString
	^'Range-HwaJong.20'! !

BaselineItem subclass: #RankingBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!RankingBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:08'!
dependingOnForVersion: aString
	^{SortDescriptorsBI}! !

!RankingBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:00'!
mczVersionNameFromMetacelloVersionString: aString
	^'Ranking-HwaJong.6'! !

BaselineItem subclass: #RemoveClassSafelyBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!RemoveClassSafelyBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:08'!
dependingOnForVersion: aString
	^{}! !

!RemoveClassSafelyBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 3/5/2014 13:05'!
mczVersionNameFromMetacelloVersionString: aString
	|mvn|
	mvn := MetacelloVersionNumber fromString: aString.
	(mvn >= (MetacelloVersionNumber fromString: '21.0')) ifTrue: [^'RemoveClassSafely-HwaJong.3'].
	^'RemoveClassSafely-HwaJong.2'! !

BaselineItem subclass: #RouletteBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!RouletteBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:08'!
dependingOnForVersion: aString
	^{SortDescriptorsBI}! !

!RouletteBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:01'!
mczVersionNameFromMetacelloVersionString: aString
	^'Roulette-HwaJong.4'! !

BaselineItem subclass: #Samgukji2AssistBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!Samgukji2AssistBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:08'!
dependingOnForVersion: aString
	^{HashProofBI. QuickPrototypingGI. MailSortingOfficeBI. LazyRabbitBI. TGListModelBI. SortDescriptorsBI. PrintingDifferentlyBI. GraphBI} ! !

!Samgukji2AssistBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 17:42'!
mczVersionNameFromMetacelloVersionString: aString
	^'Samgukji2Assist-HwaJong.10'! !

BaselineItem subclass: #SeqColSnakeBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SeqColSnakeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:08'!
dependingOnForVersion: aString
	^{}! !

!SeqColSnakeBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:02'!
mczVersionNameFromMetacelloVersionString: aString
	^'SeqColSnake-HwaJong.1'! !

BaselineItem subclass: #SieveCommonBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SieveCommonBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:09'!
dependingOnForVersion: aString
	^{AllBI. DevHelpersBaseBI. SortDescriptorsBI. DaliotBI. ClassFilterBI. TGListModelBI. LazyRabbitBI. StatisticalObjectsBI. GlueGunBI}! !

!SieveCommonBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:45'!
mczVersionNameFromMetacelloVersionString: aString
	^'SieveCommon-HwaJong.24'! !

BaselineItem subclass: #SievePharo20BI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SievePharo20BI commentStamp: '' prior: 0!
A SieveCommonBI is xxxxxxxxx.
!

!SievePharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/15/2014 08:52'!
dependingOnForVersion: aString
	^{SieveCommonBI}! !

!SievePharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:53'!
isPharo2SI
	^true! !

!SievePharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:54'!
isPharo3SI
	^true! !

!SievePharo20BI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:53'!
mczVersionNameFromMetacelloVersionString: aString
	^'SievePharo20-HwaJong.1'! !

BaselineItem subclass: #SketchupRubyBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SketchupRubyBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:09'!
dependingOnForVersion: aString
	^{DependencySorterBI}! !

!SketchupRubyBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:02'!
mczVersionNameFromMetacelloVersionString: aString
	^'SketchupRuby-hjo.3'! !

BaselineItem subclass: #SmalltalkQuizBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SmalltalkQuizBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:09'!
dependingOnForVersion: aString
	^{DistinctionBI}! !

!SmalltalkQuizBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:03'!
mczVersionNameFromMetacelloVersionString: aString
	^'SmalltalkQuiz-hjo.9'! !

BaselineItem subclass: #SortDescriptorsBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SortDescriptorsBI commentStamp: '' prior: 0!
A HashProofBI is xxxxxxxxx.
!

!SortDescriptorsBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/12/2014 03:54'!
mczVersionNameFromMetacelloVersionString: aString
	^'SortDescriptors-HwaJong.12'! !

BaselineItem subclass: #SourceCodeTourGuideCommonBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SourceCodeTourGuideCommonBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:09'!
dependingOnForVersion: aString
	^{DevHelpersBaseBI. DaliotBI. TGListModelBI. ChooseOrEnterBI. HashProofBI. DocumentLogicBI. LazyRabbitBI}! !

!SourceCodeTourGuideCommonBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:03'!
mczVersionNameFromMetacelloVersionString: aString
	^'SourceCodeTourGuideCommon-HwaJong.69'! !

BaselineItem subclass: #SourceCodeTourGuideOmniBrowserBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SourceCodeTourGuideOmniBrowserBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:10'!
dependingOnForVersion: aString
	^{SourceCodeTourGuideCommonBI}! !

!SourceCodeTourGuideOmniBrowserBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:36'!
isCommonOBSI
	^true! !

!SourceCodeTourGuideOmniBrowserBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:18'!
isCommonSI
	^false! !

!SourceCodeTourGuideOmniBrowserBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:04'!
mczVersionNameFromMetacelloVersionString: aString
	^'SourceCodeTourGuideOmniBrowser-HwaJong.5'! !

BaselineItem subclass: #StatPseudoCollectionsBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!StatPseudoCollectionsBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:10'!
dependingOnForVersion: aString
	^{MultiQuoAndRemBI. DaliotBI}! !

!StatPseudoCollectionsBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:45'!
mczVersionNameFromMetacelloVersionString: aString
	^'StatPseudoCollections-HwaJong.3'! !

BaselineItem subclass: #StatisticalObjectsBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!StatisticalObjectsBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:10'!
dependingOnForVersion: aString
	^{NumericalErrorBI. LazyRabbitBI. RangeBI}! !

!StatisticalObjectsBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:05'!
mczVersionNameFromMetacelloVersionString: aString
	^'StatisticalObjects-HwaJong.3'! !

BaselineItem subclass: #TGListModelBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!TGListModelBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:10'!
dependingOnForVersion: aString
	^{}! !

!TGListModelBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:45'!
mczVersionNameFromMetacelloVersionString: aString
	^'TGListModel-HwaJong.22'! !

BaselineItem subclass: #TechnologyTreeOptimizationOfTheCivilizationRevolutionBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!TechnologyTreeOptimizationOfTheCivilizationRevolutionBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:11'!
dependingOnForVersion: aString
	^{DependencySorterBI. HashProofBI. SortDescriptorsBI}! !

!TechnologyTreeOptimizationOfTheCivilizationRevolutionBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:06'!
mczVersionNameFromMetacelloVersionString: aString
	^'TechnologyTreeOptimizationOfTheCivilizationRevolution-HwaJong.5'! !

BaselineItem subclass: #TestableGraphicsBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!TestableGraphicsBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:11'!
dependingOnForVersion: aString
	^{}! !

!TestableGraphicsBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:07'!
mczVersionNameFromMetacelloVersionString: aString
	^'TestableGraphics-hjo.5'! !

BaselineItem subclass: #TimeComputerBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!TimeComputerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:11'!
dependingOnForVersion: aString
	^{TGListModelBI. QuickPrototypingGI. LazyRabbitBI}! !

!TimeComputerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:07'!
mczVersionNameFromMetacelloVersionString: aString
	^'TimeComputer-HwaJong.1'! !

BaselineItem subclass: #TinyTowerBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!TinyTowerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 3/25/2014 20:59'!
dependingOnForVersion: aString
	|mvn|
	mvn := MetacelloVersionNumber fromString: aString.
	(mvn >= (MetacelloVersionNumber fromString: '8.8-baseline')) ifTrue: [^{HashProofBI. TGListModelBI. QuickPrototypingGI. LazyRabbitBI. SortDescriptorsBI. PrintingDifferentlyBI. ChooseOrEnterBI. GGControllerBI}].
	(mvn >= (MetacelloVersionNumber fromString: '8.7-baseline')) ifTrue: [^{HashProofBI. TGListModelBI. QuickPrototypingGI. LazyRabbitBI. SortDescriptorsBI. PrintingDifferentlyBI. ChooseOrEnterBI}].
	^super dependingOnForVersion: aString! !

!TinyTowerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 3/25/2014 20:57'!
mczVersionNameFromMetacelloVersionString: aString
	|mvn|
	mvn := MetacelloVersionNumber fromString: aString.
	(mvn >= (MetacelloVersionNumber fromString: '21.3')) ifTrue: [^'TinyTower-HwaJong.6'].
	(mvn >= (MetacelloVersionNumber fromString: '21.2')) ifTrue: [^'TinyTower-HwaJong.5'].
	(mvn >= (MetacelloVersionNumber fromString: '21.0')) ifTrue: [^'TinyTower-HwaJong.4'].
	^'TinyTower-HwaJong.2'! !

BaselineItem subclass: #UndoRedoBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!UndoRedoBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:11'!
dependingOnForVersion: aString
	^{LazyRabbitBI}! !

!UndoRedoBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:20'!
mczVersionNameFromMetacelloVersionString: aString
	^'UndoRedo-HwaJong.2'! !

BaselineItem subclass: #UnificationBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!UnificationBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:12'!
dependingOnForVersion: aString
	^{ClassFilterBI}! !

!UnificationBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:20'!
mczVersionNameFromMetacelloVersionString: aString
	^'Unification-HwaJong.11'! !

BaselineItem subclass: #WaffleLayoutBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!WaffleLayoutBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:12'!
dependingOnForVersion: aString
	^{RangeBI. LazyRabbitBI}! !

!WaffleLayoutBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:21'!
mczVersionNameFromMetacelloVersionString: aString
	^'WaffleLayout-HwaJong.19'! !

BaselineItem subclass: #WoodCutPicturesBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!WoodCutPicturesBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:12'!
dependingOnForVersion: aString
	^{TestableGraphicsBI}! !

!WoodCutPicturesBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:52'!
mczVersionNameFromMetacelloVersionString: aString
	^'WoodCutPictures-HwaJong.8'! !

BaselineItem subclass: #WorkPlayRatioSchedulerBI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!WorkPlayRatioSchedulerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:12'!
dependingOnForVersion: aString
	^{WaffleLayoutBI. LazyRabbitBI. CenterStringBI}! !

!WorkPlayRatioSchedulerBI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:22'!
mczVersionNameFromMetacelloVersionString: aString
	^'WorkPlayRatioScheduler-HwaJong.13'! !

SpecItem subclass: #GroupItem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

GroupItem subclass: #DevHelpersGI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DevHelpersGI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:59'!
groupElements
	^{DevPacerGI. CopyHierarchyBI. SieveGI. SourceCodeTourGuideGI}.! !

!DevHelpersGI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:38'!
isCommonSI
	^false! !

GroupItem subclass: #DevPacerGI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!DevPacerGI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:00'!
groupElements
	^{DevPacerPharo20BI. DevPacerCommonBI}.! !

!DevPacerGI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:38'!
isCommonSI
	^false! !

!GroupItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:58'!
defineSpec: spec forBaselineVersionString: aString 
	spec group: self groupName with: (self groupElements collect: #specName).! !

!GroupItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 20:57'!
defineSpec: spec withVersionString: aString ! !

!GroupItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 01:53'!
groupName
	^self specName! !

!GroupItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 01:50'!
postFix

	^'GI'! !

GroupItem subclass: #QuickPrototypingGI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!QuickPrototypingGI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:00'!
groupElements
	^{QuickPrototypingCommonBI. QuickPrototypingPharo20BI}.! !

GroupItem subclass: #SieveGI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SieveGI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:00'!
groupElements
	^{SieveCommonBI. SievePharo20BI}.! !

GroupItem subclass: #SourceCodeTourGuideCoreGI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SourceCodeTourGuideCoreGI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:00'!
groupElements
	^{SourceCodeTourGuideCommonBI}.! !

GroupItem subclass: #SourceCodeTourGuideGI
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfDaliotsPlayground'!

!SourceCodeTourGuideGI class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 21:00'!
groupElements
	^{SourceCodeTourGuideCoreGI}.! !

!SpecItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:15'!
concreteSubclasses
	^self allSubclasses copyWithoutAll: { GroupItem. BaselineItem}! !

!SpecItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:36'!
isCommonOBSI
	^false! !

!SpecItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:36'!
isCommonSI
	^true! !

!SpecItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:37'!
isPharo2SI
	^false! !

!SpecItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 02:37'!
isPharo3SI
	^false! !

!SpecItem class methodsFor: 'as yet unclassified ' stamp: 'HwaJong 2/13/2014 18:07'!
loadLastVersion
	ConfigurationOfDaliotsPlayground project versions last load: self specName.! !

!SpecItem class methodsFor: 'as yet unclassified' stamp: 'HwaJong 2/13/2014 01:53'!
specName
	| index |
	index := self className indexOfSubCollection: self postFix.
	^self className first: index-1! !
